@@ -408,7 +408,7 @@ _OptionalElasticsearchDomainStatusTypeDef = TypedDict(
         "NodeToNodeEncryptionOptions": "NodeToNodeEncryptionOptionsTypeDef",
         "AdvancedOptions": Dict[str, str],
         "LogPublishingOptions": Dict[
-            Literal["INDEX_SLOW_LOGS", "SEARCH_SLOW_LOGS", "ES_APPLICATION_LOGS"],
+            Literal["INDEX_SLOW_LOGS", "SEARCH_SLOW_LOGS", "ES_APPLICATION_LOGS", "AUDIT_LOGS"],
             "LogPublishingOptionTypeDef",
         ],
         "ServiceSoftwareOptions": "ServiceSoftwareOptionsTypeDef",
@@ -492,7 +492,7 @@ LogPublishingOptionsStatusTypeDef = TypedDict(
     "LogPublishingOptionsStatusTypeDef",
     {
         "Options": Dict[
-            Literal["INDEX_SLOW_LOGS", "SEARCH_SLOW_LOGS", "ES_APPLICATION_LOGS"],
+            Literal["INDEX_SLOW_LOGS", "SEARCH_SLOW_LOGS", "ES_APPLICATION_LOGS", "AUDIT_LOGS"],
             "LogPublishingOptionTypeDef",
         ],
         "Status": "OptionStatusTypeDef",
